import { Directive, Renderer2, ElementRef, Input, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxOverflowShadowDirective {
    /**
     * @param {?} renderer
     * @param {?} elementRef
     */
    constructor(renderer, elementRef) {
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.shadowStyle = '0 0 8px 1px rgba(0, 0, 0, 0.8)';
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        const { nativeElement } = this.elementRef;
        this.observer = new IntersectionObserver(this.callback.bind(this), { root: nativeElement });
        this.createBottomPlaceholderDiv(nativeElement);
        this.createBottomShadowDiv(nativeElement);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.observer.disconnect();
    }
    /**
     * @private
     * @param {?} nativeElement
     * @return {?}
     */
    createBottomPlaceholderDiv(nativeElement) {
        /** @type {?} */
        const bottomPlaceholderDiv = this.renderer.createElement('div');
        this.renderer.appendChild(nativeElement, bottomPlaceholderDiv);
        this.observer.observe(bottomPlaceholderDiv);
    }
    /**
     * @private
     * @param {?} nativeElement
     * @return {?}
     */
    createBottomShadowDiv(nativeElement) {
        this.bottomShadowDiv = this.renderer.createElement('div');
        Object.keys(NgxOverflowShadowDirective.DEFAULT_STYLE).forEach((/**
         * @param {?} prop
         * @return {?}
         */
        (prop) => {
            this.renderer.setStyle(this.bottomShadowDiv, prop, NgxOverflowShadowDirective.DEFAULT_STYLE[prop]);
        }));
        this.renderer.appendChild(nativeElement, this.bottomShadowDiv);
    }
    /**
     * @private
     * @param {?} entries
     * @return {?}
     */
    callback(entries) {
        const { isIntersecting } = entries[0];
        console.log(entries);
        if (isIntersecting) {
            this.renderer.removeStyle(this.bottomShadowDiv, 'boxShadow');
        }
        else {
            this.renderer.setStyle(this.bottomShadowDiv, 'boxShadow', this.shadowStyle);
        }
    }
}
NgxOverflowShadowDirective.DEFAULT_STYLE = {
    position: 'sticky',
    bottom: 0
};
NgxOverflowShadowDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxOverflowShadow]'
            },] }
];
/** @nocollapse */
NgxOverflowShadowDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef }
];
NgxOverflowShadowDirective.propDecorators = {
    shadowStyle: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxOverflowShadowModule {
}
NgxOverflowShadowModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxOverflowShadowDirective],
                exports: [NgxOverflowShadowDirective]
            },] }
];

export { NgxOverflowShadowDirective, NgxOverflowShadowModule };
//# sourceMappingURL=ngx-overflow-shadow.js.map
